pub struct Extent {
pub offset: u64,
pub size: u32,
}Expand description
An extent containing a file’s data on disk.
This is created by the extents method on File, and represents
a byte range on the disk that contains a file’s data. All values
are in bytes.
Fields
offset: u64size: u32Trait Implementations