StdIoWrapper

Struct StdIoWrapper 

pub struct StdIoWrapper<T> { /* private fields */ }
A wrapper struct for types that have implementations for std::io traits.

Read, Write, Seek traits from this crate are implemented for this type if corresponding types from std::io are implemented by the inner instance.

Implementations

Source

impl<T> StdIoWrapper<T>

pub fn new(inner: T) -> Self

Creates a new StdIoWrapper instance that wraps the provided inner instance.

pub fn into_inner(self) -> T

Returns inner struct