pub struct File<'a, IO: ReadWriteSeek, TP, OCC> { /* private fields */ }Expand description
A FAT filesystem file object used for reading and writing data.
This struct is created by the open_file or create_file methods on Dir.
Implementations
Sourceimpl<'a, IO: ReadWriteSeek, TP, OCC> File<'a, IO, TP, OCC>
impl<'a, IO: ReadWriteSeek, TP, OCC> File<'a, IO, TP, OCC>
Sourcepub fn extents(
&mut self,
) -> impl Iterator<Item = Result<Extent, Error<IO::Error>>> + 'a
pub fn extents( &mut self, ) -> impl Iterator<Item = Result<Extent, Error<IO::Error>>> + 'a
Get the extents of a file on disk.
This returns an iterator over the byte ranges on-disk occupied by this file.
Sourcepub fn set_created(&mut self, date_time: DateTime)
👎Deprecated
pub fn set_created(&mut self, date_time: DateTime)
Sets date and time of creation for this file.
Note: it is set to a value from the TimeProvider when creating a file.
Sourcepub fn set_accessed(&mut self, date: Date)
👎Deprecated
pub fn set_accessed(&mut self, date: Date)
Sets date of last access for this file.
Note: it is overwritten by a value from the TimeProvider on every file read operation.
Sourcepub fn set_modified(&mut self, date_time: DateTime)
👎Deprecated
pub fn set_modified(&mut self, date_time: DateTime)
Sets date and time of last modification for this file.
Note: it is overwritten by a value from the TimeProvider on every file write operation.
pub fn size(&self) -> Option<u32>