pub struct StdIoWrapper<T> { /* private fields */ }Expand description
A wrapper struct for types that have implementations for std::io traits.
Read, Write, Seek traits from this crate are implemented for this type if
corresponding types from std::io are implemented by the inner instance.
Implementations
Sourceimpl<T> StdIoWrapper<T>
impl<T> StdIoWrapper<T>
Sourcepub fn new(inner: T) -> Self
pub fn new(inner: T) -> Self
Creates a new StdIoWrapper instance that wraps the provided inner instance.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Returns inner struct